@@ -14,15 +14,16 @@
 static GWENHYWFAR_CB
 int Gtk2Gui_WLineEdit_SetIntProperty(GWEN_WIDGET *w,
                                      GWEN_DIALOG_PROPERTY prop,
-                                     int index,
+                                     GWEN_UNUSED int index,
                                      int value,
-                                     int doSignal) {
+                                     GWEN_UNUSED int doSignal)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     gtk_widget_set_sensitive(GTK_WIDGET(g), (value==0)?FALSE:TRUE);
     return 0;
@@ -52,14 +53,15 @@ int Gtk2Gui_WLineEdit_SetIntProperty(GWEN_WIDGET *w,
 static GWENHYWFAR_CB
 int Gtk2Gui_WLineEdit_GetIntProperty(GWEN_WIDGET *w,
                                      GWEN_DIALOG_PROPERTY prop,
-                                     int index,
-                                     int defaultValue) {
+                                     GWEN_UNUSED int index,
+                                     int defaultValue)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     return (gtk_widget_get_sensitive(GTK_WIDGET(g))==TRUE)?1:0;
 
@@ -87,15 +89,16 @@ int Gtk2Gui_WLineEdit_GetIntProperty(GWEN_WIDGET *w,
 static GWENHYWFAR_CB
 int Gtk2Gui_WLineEdit_SetCharProperty(GWEN_WIDGET *w,
                                       GWEN_DIALOG_PROPERTY prop,
-                                      int index,
+                                      GWEN_UNUSED int index,
                                       const char *value,
-                                      int doSignal) {
+                                      GWEN_UNUSED int doSignal)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Value:
     gtk_entry_set_text(GTK_ENTRY(g), value);
     return 0;
@@ -112,16 +115,17 @@ int Gtk2Gui_WLineEdit_SetCharProperty(GWEN_WIDGET *w,
 
 
 static GWENHYWFAR_CB
-const char* Gtk2Gui_WLineEdit_GetCharProperty(GWEN_WIDGET *w,
-    GWEN_DIALOG_PROPERTY prop,
-    int index,
-    const char *defaultValue) {
+const char *Gtk2Gui_WLineEdit_GetCharProperty(GWEN_WIDGET *w,
+                                              GWEN_DIALOG_PROPERTY prop,
+                                              GWEN_UNUSED int index,
+                                              const char *defaultValue)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Value:
     return gtk_entry_get_text(GTK_ENTRY(g));
   default:
@@ -136,10 +140,11 @@ const char* Gtk2Gui_WLineEdit_GetCharProperty(GWEN_WIDGET *w,
 
 
 
-static void Gtk2Gui_WLineEdit_Deleted_text_handler(GtkEntryBuffer *entrybuffer,
-    guint arg1,
-    guint arg2,
-    gpointer data) {
+static void Gtk2Gui_WLineEdit_Deleted_text_handler(GWEN_UNUSED GtkEntryBuffer *entrybuffer,
+                                                   GWEN_UNUSED guint arg1,
+                                                   GWEN_UNUSED guint arg2,
+                                                   gpointer data)
+{
   GWEN_WIDGET *w;
   int rv;
 
@@ -156,11 +161,12 @@ static void Gtk2Gui_WLineEdit_Deleted_text_handler(GtkEntryBuffer *entrybuffer,
 
 
 
-static void Gtk2Gui_WLineEdit_Inserted_text_handler(GtkEntryBuffer *entrybuffer,
-    guint arg1,
-    gchar *arg2,
-    guint arg3,
-    gpointer data) {
+static void Gtk2Gui_WLineEdit_Inserted_text_handler(GWEN_UNUSED GtkEntryBuffer *entrybuffer,
+                                                    GWEN_UNUSED guint arg1,
+                                                    GWEN_UNUSED gchar *arg2,
+                                                    GWEN_UNUSED guint arg3,
+                                                    gpointer data)
+{
   GWEN_WIDGET *w;
   int rv;
 
@@ -177,13 +183,14 @@ static void Gtk2Gui_WLineEdit_Inserted_text_handler(GtkEntryBuffer *entrybuffer,
 
 
 
-int Gtk2Gui_WLineEdit_Setup(GWEN_WIDGET *w) {
+int Gtk2Gui_WLineEdit_Setup(GWEN_WIDGET *w)
+{
   GtkWidget *g;
   const char *s;
   uint32_t flags;
   GWEN_WIDGET *wParent;
-  gulong deleted_text_handler_id;
-  gulong inserted_text_handler_id;
+  /*gulong deleted_text_handler_id;*/
+  /*gulong inserted_text_handler_id;*/
   gboolean text_is_visible;
 
   flags=GWEN_Widget_GetFlags(w);
@@ -197,23 +204,23 @@ int Gtk2Gui_WLineEdit_Setup(GWEN_WIDGET *w) {
     gtk_entry_set_text(GTK_ENTRY(g), s);
   gtk_entry_set_visibility(GTK_ENTRY(g), text_is_visible);
 
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void*) g);
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void*) g);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void *) g);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void *) g);
 
   GWEN_Widget_SetSetIntPropertyFn(w, Gtk2Gui_WLineEdit_SetIntProperty);
   GWEN_Widget_SetGetIntPropertyFn(w, Gtk2Gui_WLineEdit_GetIntProperty);
   GWEN_Widget_SetSetCharPropertyFn(w, Gtk2Gui_WLineEdit_SetCharProperty);
   GWEN_Widget_SetGetCharPropertyFn(w, Gtk2Gui_WLineEdit_GetCharProperty);
 
-  deleted_text_handler_id=g_signal_connect(gtk_entry_get_buffer(GTK_ENTRY(g)),
-                          "deleted-text",
-                          G_CALLBACK (Gtk2Gui_WLineEdit_Deleted_text_handler),
-                          w);
+  /*deleted_text_handler_id=*/g_signal_connect(gtk_entry_get_buffer(GTK_ENTRY(g)),
+                                               "deleted-text",
+                                               G_CALLBACK(Gtk2Gui_WLineEdit_Deleted_text_handler),
+                                               w);
 
-  inserted_text_handler_id=g_signal_connect(gtk_entry_get_buffer(GTK_ENTRY(g)),
-                           "inserted-text",
-                           G_CALLBACK (Gtk2Gui_WLineEdit_Inserted_text_handler),
-                           w);
+  /*inserted_text_handler_id=*/g_signal_connect(gtk_entry_get_buffer(GTK_ENTRY(g)),
+                                                "inserted-text",
+                                                G_CALLBACK(Gtk2Gui_WLineEdit_Inserted_text_handler),
+                                                w);
 
   if (wParent)
     GWEN_Widget_AddChildGuiWidget(wParent, w);
